@@ -9,16 +9,17 @@ from collections import OrderedDict
 
 import dns
 import ipaddress
-from pyleri import (Grammar,
-                    Regex,
-                    Sequence,
-                    Repeat
-                    )
+from pyleri import Grammar, Regex, Sequence, Repeat
 
 from checkdmarc._constants import SYNTAX_ERROR_MARKER
-from checkdmarc.utils import (query_dns, get_a_records,
-                              get_txt_records, get_mx_records,
-                              DNSException, DNSExceptionNXDOMAIN)
+from checkdmarc.utils import (
+    query_dns,
+    get_a_records,
+    get_txt_records,
+    get_mx_records,
+    DNSException,
+    DNSExceptionNXDOMAIN,
+)
 
 """Copyright 2019-2023 Sean Whalen
 
@@ -37,10 +38,10 @@ limitations under the License."""
 SPF_VERSION_TAG_REGEX_STRING = "v=spf1"
 SPF_MECHANISM_REGEX_STRING = (
     r"([+\-~?])?"
-    r"(mx:?|ip4:?|ip6:?|exists:?|include:?|all:?|a:?|redirect=|exp:?|ptr:?)"
+    r"(mx:?|ip4:?|ip6:?|exists:?|include:?|all:?|a:?|redirect=|exp:?|ptr:?|ra=|rp=|rr=)"
     r"([\w+/_.:\-{%}]*)"
 )
-AFTER_ALL_REGEX_STRING = r"\ball\s*[^\s]+"
+AFTER_ALL_REGEX_STRING = r"([\s^][+\-~?]?all)\s+.*"
 
 SPF_MECHANISM_REGEX = re.compile(SPF_MECHANISM_REGEX_STRING, re.IGNORECASE)
 AFTER_ALL_REGEX = re.compile(AFTER_ALL_REGEX_STRING, re.IGNORECASE)
@@ -65,7 +66,7 @@ class _SPFWarning(Exception):
 
 class _SPFMissingRecords(_SPFWarning):
     """Raised when a mechanism in a ``SPF`` record is missing the requested
-       A/AAAA or MX records"""
+    A/AAAA or MX records"""
 
 
 class _SPFDuplicateInclude(_SPFWarning):
@@ -86,6 +87,10 @@ class MultipleSPFRTXTRecords(SPFError):
     """Raised when multiple TXT spf1 records are found"""
 
 
+class UndecodableCharactersInTXTRecord(_SPFWarning):
+    """Raised when a TXT record contains one or more undecodable characters"""
+
+
 class SPFSyntaxError(SPFError):
     """Raised when an SPF syntax error is found"""
 
@@ -116,24 +121,21 @@ class SPFIncludeLoop(SPFError):
 
 class _SPFGrammar(Grammar):
     """Defines Pyleri grammar for SPF records"""
+
     version_tag = Regex(SPF_VERSION_TAG_REGEX_STRING)
     mechanism = Regex(SPF_MECHANISM_REGEX_STRING, re.IGNORECASE)
     START = Sequence(version_tag, Repeat(mechanism))
 
 
-spf_qualifiers = {
-    "": "pass",
-    "?": "neutral",
-    "+": "pass",
-    "-": "fail",
-    "~": "softfail"
-}
+spf_qualifiers = {"": "pass", "?": "neutral", "+": "pass", "-": "fail", "~": "softfail"}
 
 
-def query_spf_record(domain: str,
-                     nameservers: list[str] = None,
-                     resolver: dns.resolver.Resolver = None,
-                     timeout: float = 2.0) -> OrderedDict:
+def query_spf_record(
+    domain: str,
+    nameservers: list[str] = None,
+    resolver: dns.resolver.Resolver = None,
+    timeout: float = 2.0,
+) -> OrderedDict:
     """
     Queries DNS for an SPF record
 
@@ -158,43 +160,45 @@ def query_spf_record(domain: str,
     spf_type_records = []
     spf_txt_records = []
     try:
-        spf_type_records += query_dns(domain, "SPF",
-                                      nameservers=nameservers,
-                                      resolver=resolver, timeout=timeout)
+        spf_type_records += query_dns(
+            domain, "SPF", nameservers=nameservers, resolver=resolver, timeout=timeout
+        )
     except (dns.resolver.NoAnswer, Exception):
         pass
 
     if len(spf_type_records) > 0:
-        message = "SPF type DNS records found. Use of DNS Type SPF has been " \
-                  "removed in the standards " \
-                  "track version of SPF, RFC 7208. These records should " \
-                  "be removed and replaced with TXT records: " \
-                  f"{','.join(spf_type_records)}"
+        message = (
+            "SPF type DNS records found. Use of DNS Type SPF has been "
+            "removed in the standards "
+            "track version of SPF, RFC 7208. These records should "
+            "be removed and replaced with TXT records: "
+            f"{','.join(spf_type_records)}"
+        )
         warnings.append(message)
     try:
-        answers = query_dns(domain, "TXT", nameservers=nameservers,
-                            resolver=resolver, timeout=timeout)
+        answers = query_dns(
+            domain, "TXT", nameservers=nameservers, resolver=resolver, timeout=timeout
+        )
         spf_record = None
         for record in answers:
+            if record == "Undecodable characters":
+                raise UndecodableCharactersInTXTRecord(
+                    f"A TXT record at {domain} " "contains undecodable " "characters"
+                )
             if record.startswith(txt_prefix):
                 spf_txt_records.append(record)
         if len(spf_txt_records) > 1:
-            raise MultipleSPFRTXTRecords(
-                f"{domain} has multiple SPF TXT records")
+            raise MultipleSPFRTXTRecords(f"{domain} has multiple SPF TXT records")
         elif len(spf_txt_records) == 1:
             spf_record = spf_txt_records[0]
         if spf_record is None:
             raise SPFRecordNotFound(
-                f"{domain} "
-                f"does not have a SPF TXT record",
-                domain)
+                f"{domain} " f"does not have a SPF TXT record", domain
+            )
     except dns.resolver.NoAnswer:
-        raise SPFRecordNotFound(
-            f"{domain} does not have a SPF TXT record",
-            domain)
+        raise SPFRecordNotFound(f"{domain} does not have a SPF TXT record", domain)
     except dns.resolver.NXDOMAIN:
-        raise SPFRecordNotFound(f"The domain {domain} does not exist",
-                                domain)
+        raise SPFRecordNotFound(f"The domain {domain} does not exist", domain)
     except Exception as error:
         raise SPFRecordNotFound(error, domain)
 
@@ -202,13 +206,16 @@ def query_spf_record(domain: str,
 
 
 def parse_spf_record(
-        record: str, domain: str,
-        parked: bool = False, seen: bool = None,
-        nameservers: list[str] = None,
-        resolver: dns.resolver.Resolver = None,
-        recursion: OrderedDict = None,
-        timeout: float = 2.0,
-        syntax_error_marker: str = SYNTAX_ERROR_MARKER) -> OrderedDict:
+    record: str,
+    domain: str,
+    parked: bool = False,
+    seen: bool = None,
+    nameservers: list[str] = None,
+    resolver: dns.resolver.Resolver = None,
+    recursion: OrderedDict = None,
+    timeout: float = 2.0,
+    syntax_error_marker: str = SYNTAX_ERROR_MARKER,
+) -> OrderedDict:
     """
     Parses an SPF record, including resolving ``a``, ``mx``, and ``include``
     mechanisms
@@ -243,41 +250,49 @@ def parse_spf_record(
         seen = [domain]
     if recursion is None:
         recursion = [domain]
-    record = record.replace('" ', '').replace('"', '')
+    record = record.replace('" ', "").replace('"', "")
     warnings = []
     spf_syntax_checker = _SPFGrammar()
     if parked:
         correct_record = "v=spf1 -all"
         if record != correct_record:
-            warnings.append("The SPF record for parked domains should be: "
-                            f"{correct_record} not: {record}")
+            warnings.append(
+                "The SPF record for parked domains should be: "
+                f"{correct_record} not: {record}"
+            )
     if len(AFTER_ALL_REGEX.findall(record)) > 0:
         warnings.append("Any text after the all mechanism is ignored")
-        record = AFTER_ALL_REGEX.sub("all", record)
+        record = AFTER_ALL_REGEX.sub(r"\1", record)
     parsed_record = spf_syntax_checker.parse(record)
     if not parsed_record.is_valid:
         pos = parsed_record.pos
         expecting = list(
-            map(lambda x: str(x).strip('"'), list(parsed_record.expecting)))
+            map(lambda x: str(x).strip('"'), list(parsed_record.expecting))
+        )
         expecting = " or ".join(expecting)
         marked_record = record[:pos] + syntax_error_marker + record[pos:]
         raise SPFSyntaxError(
             f"{domain}: Expected {expecting} at position {pos} "
-            f"(marked with {syntax_error_marker}) in: {marked_record}")
+            f"(marked with {syntax_error_marker}) in: {marked_record}"
+        )
     matches = SPF_MECHANISM_REGEX.findall(record.lower())
-    parsed = OrderedDict([("pass", []),
-                          ("neutral", []),
-                          ("softfail", []),
-                          ("fail", []),
-                          ("include", []),
-                          ("redirect", None),
-                          ("exp", None),
-                          ("all", "neutral")])
+    parsed = OrderedDict(
+        [
+            ("pass", []),
+            ("neutral", []),
+            ("softfail", []),
+            ("fail", []),
+            ("include", []),
+            ("redirect", None),
+            ("exp", None),
+            ("all", "neutral"),
+        ]
+    )
 
     lookup_mechanism_count = 0
     void_lookup_mechanism_count = 0
     for match in matches:
-        mechanism = match[1].lower().strip(':=')
+        mechanism = match[1].lower().strip(":=")
         if mechanism in lookup_mechanisms:
             lookup_mechanism_count += 1
     if lookup_mechanism_count > 10:
@@ -285,79 +300,99 @@ def parse_spf_record(
             "Parsing the SPF record requires "
             f"{lookup_mechanism_count}/10 maximum DNS lookups - "
             "https://tools.ietf.org/html/rfc7208#section-4.6.4",
-            dns_lookups=lookup_mechanism_count)
+            dns_lookups=lookup_mechanism_count,
+        )
 
     for match in matches:
         result = spf_qualifiers[match[0]]
-        mechanism = match[1].strip(':=')
+        mechanism = match[1].strip(":=")
         value = match[2]
 
         try:
             if mechanism == "ip4":
                 try:
-                    if not isinstance(ipaddress.ip_network(value,
-                                                           strict=False),
-                                      ipaddress.IPv4Network):
-                        raise SPFSyntaxError(f"{value} is not a valid ipv4  "
-                                             "value. Looks like ipv6")
+                    if not isinstance(
+                        ipaddress.ip_network(value, strict=False), ipaddress.IPv4Network
+                    ):
+                        raise SPFSyntaxError(
+                            f"{value} is not a valid ipv4  " "value. Looks like ipv6"
+                        )
                 except ValueError:
                     raise SPFSyntaxError(f"{value} is not a valid ipv4 value")
             elif mechanism == "ip6":
                 try:
-                    if not isinstance(ipaddress.ip_network(value,
-                                                           strict=False),
-                                      ipaddress.IPv6Network):
-                        raise SPFSyntaxError(f"{value} is not a valid ipv6 "
-                                             "value. Looks like ipv4")
+                    if not isinstance(
+                        ipaddress.ip_network(value, strict=False), ipaddress.IPv6Network
+                    ):
+                        raise SPFSyntaxError(
+                            f"{value} is not a valid ipv6 " "value. Looks like ipv4"
+                        )
                 except ValueError:
                     raise SPFSyntaxError(f"{value} is not a valid ipv6 value")
 
             if mechanism == "a":
                 if value == "":
                     value = domain
-                a_records = get_a_records(value, nameservers=nameservers,
-                                          resolver=resolver, timeout=timeout)
+                cidr = None
+                value = value.split("/")
+                value = value[0]
+                if len(value) == 2:
+                    cidr = value[1]
+                a_records = get_a_records(
+                    value, nameservers=nameservers, resolver=resolver, timeout=timeout
+                )
                 if len(a_records) == 0:
                     raise _SPFMissingRecords(
-                        f"{value.lower()} does not have any A/AAAA records")
+                        f"{value.lower()} does not have any A/AAAA records"
+                    )
                 for record in a_records:
-                    parsed[result].append(OrderedDict(
-                        [("value", record), ("mechanism", mechanism)]))
+                    if cidr:
+                        record = f"{record}/{cidr}"
+                    parsed[result].append(
+                        OrderedDict([("value", record), ("mechanism", mechanism)])
+                    )
             elif mechanism == "mx":
                 if value == "":
                     value = domain
-                mx_hosts = get_mx_records(value, nameservers=nameservers,
-                                          resolver=resolver, timeout=timeout)
+                mx_hosts = get_mx_records(
+                    value, nameservers=nameservers, resolver=resolver, timeout=timeout
+                )
                 if len(mx_hosts) == 0:
                     raise _SPFMissingRecords(
-                        f"{value.lower()} does not have any MX records")
+                        f"{value.lower()} does not have any MX records"
+                    )
                 if len(mx_hosts) > 10:
                     url = "https://tools.ietf.org/html/rfc7208#section-4.6.4"
                     raise SPFTooManyDNSLookups(
                         f"{value} has more than 10 MX records - {url}",
-                        dns_lookups=len(mx_hosts))
+                        dns_lookups=len(mx_hosts),
+                    )
                 for host in mx_hosts:
                     hostname = host["hostname"]
-                    parsed[result].append(OrderedDict(
-                        [("value", hostname),
-                         ("mechanism", mechanism)]))
+                    parsed[result].append(
+                        OrderedDict([("value", hostname), ("mechanism", mechanism)])
+                    )
             elif mechanism == "redirect":
                 if value.lower() in recursion:
                     raise SPFRedirectLoop(f"Redirect loop: {value.lower()}")
                 seen.append(value.lower())
                 try:
-                    redirect_record = query_spf_record(value,
-                                                       nameservers=nameservers,
-                                                       resolver=resolver,
-                                                       timeout=timeout)
+                    redirect_record = query_spf_record(
+                        value,
+                        nameservers=nameservers,
+                        resolver=resolver,
+                        timeout=timeout,
+                    )
                     redirect_record = redirect_record["record"]
-                    redirect = parse_spf_record(redirect_record, value,
-                                                seen=seen,
-                                                recursion=recursion + [
-                                                    value.lower()],
-                                                nameservers=nameservers,
-                                                resolver=resolver,
-                                                timeout=timeout)
+                    redirect = parse_spf_record(
+                        redirect_record,
+                        value,
+                        seen=seen,
+                        recursion=recursion + [value.lower()],
+                        nameservers=nameservers,
+                        resolver=resolver,
+                        timeout=timeout,
+                    )
                     lookup_mechanism_count += redirect["dns_lookups"]
                     void_lookup_mechanism_count += redirect["dns_void_lookups"]
                     if lookup_mechanism_count > 10:
@@ -367,7 +402,8 @@ def parse_spf_record(
                             "DNS lookups - "
                             "https://tools.ietf.org/html/rfc7208"
                             "#section-4.6.4",
-                            dns_lookups=lookup_mechanism_count)
+                            dns_lookups=lookup_mechanism_count,
+                        )
                     if void_lookup_mechanism_count > 2:
                         u = "https://tools.ietf.org/html/rfc7208#section-4.6.4"
                         raise SPFTooManyVoidDNSLookups(
@@ -375,13 +411,18 @@ def parse_spf_record(
                             f"{void_lookup_mechanism_count}/2 maximum void "
                             "DNS lookups - "
                             f"{u}",
-                            dns_void_lookups=void_lookup_mechanism_count)
+                            dns_void_lookups=void_lookup_mechanism_count,
+                        )
                     parsed["redirect"] = OrderedDict(
-                        [("domain", value), ("record", redirect_record),
-                         ("dns_lookups", redirect["dns_lookups"]),
-                         ("dns_void_lookups", redirect["dns_void_lookups"]),
-                         ("parsed", redirect["parsed"]),
-                         ("warnings", redirect["warnings"])])
+                        [
+                            ("domain", value),
+                            ("record", redirect_record),
+                            ("dns_lookups", redirect["dns_lookups"]),
+                            ("dns_void_lookups", redirect["dns_void_lookups"]),
+                            ("parsed", redirect["parsed"]),
+                            ("warnings", redirect["warnings"]),
+                        ]
+                    )
                     warnings += redirect["warnings"]
                 except DNSException as error:
                     if isinstance(error, DNSExceptionNXDOMAIN):
@@ -396,27 +437,29 @@ def parse_spf_record(
                     pointer = " -> ".join(recursion + [value.lower()])
                     raise SPFIncludeLoop(f"Include loop: {pointer}")
                 if value.lower() in seen:
-                    raise _SPFDuplicateInclude(
-                        f"Duplicate include: {value.lower()}")
+                    raise _SPFDuplicateInclude(f"Duplicate include: {value.lower()}")
                 seen.append(value.lower())
                 if "%{" in value:
-                    include = OrderedDict(
-                        [("domain", value)])
+                    include = OrderedDict([("domain", value)])
                     parsed["include"].append(include)
                     continue
                 try:
-                    include_record = query_spf_record(value,
-                                                      nameservers=nameservers,
-                                                      resolver=resolver,
-                                                      timeout=timeout)
+                    include_record = query_spf_record(
+                        value,
+                        nameservers=nameservers,
+                        resolver=resolver,
+                        timeout=timeout,
+                    )
                     include_record = include_record["record"]
-                    include = parse_spf_record(include_record, value,
-                                               seen=seen,
-                                               recursion=recursion + [
-                                                   value.lower()],
-                                               nameservers=nameservers,
-                                               resolver=resolver,
-                                               timeout=timeout)
+                    include = parse_spf_record(
+                        include_record,
+                        value,
+                        seen=seen,
+                        recursion=recursion + [value.lower()],
+                        nameservers=nameservers,
+                        resolver=resolver,
+                        timeout=timeout,
+                    )
                     lookup_mechanism_count += include["dns_lookups"]
                     void_lookup_mechanism_count += include["dns_void_lookups"]
                     if lookup_mechanism_count > 10:
@@ -426,7 +469,8 @@ def parse_spf_record(
                             "DNS lookups - "
                             "https://tools.ietf.org/html/rfc7208"
                             "#section-4.6.4",
-                            dns_lookups=lookup_mechanism_count)
+                            dns_lookups=lookup_mechanism_count,
+                        )
                     if void_lookup_mechanism_count > 2:
                         u = "https://tools.ietf.org/html/rfc7208#section-4.6.4"
                         raise SPFTooManyVoidDNSLookups(
@@ -434,13 +478,18 @@ def parse_spf_record(
                             f"{void_lookup_mechanism_count}/2 maximum void "
                             "DNS lookups - "
                             f"{u}",
-                            dns_void_lookups=void_lookup_mechanism_count)
+                            dns_void_lookups=void_lookup_mechanism_count,
+                        )
                     include = OrderedDict(
-                        [("domain", value), ("record", include_record),
-                         ("dns_lookups", include["dns_lookups"]),
-                         ("dns_void_lookups", include["dns_void_lookups"]),
-                         ("parsed", include["parsed"]),
-                         ("warnings", include["warnings"])])
+                        [
+                            ("domain", value),
+                            ("record", include_record),
+                            ("dns_lookups", include["dns_lookups"]),
+                            ("dns_void_lookups", include["dns_void_lookups"]),
+                            ("parsed", include["parsed"]),
+                            ("warnings", include["warnings"]),
+                        ]
+                    )
                     parsed["include"].append(include)
                     warnings += include["warnings"]
 
@@ -453,13 +502,38 @@ def parse_spf_record(
                     raise error
             elif mechanism == "ptr":
                 parsed[result].append(
-                    OrderedDict([("value", value), ("mechanism", mechanism)]))
-                raise _SPFWarning("The ptr mechanism should not be used - "
-                                  "https://tools.ietf.org/html/rfc7208"
-                                  "#section-5.5")
+                    OrderedDict([("value", value), ("mechanism", mechanism)])
+                )
+                raise _SPFWarning(
+                    "The ptr mechanism should not be used - "
+                    "https://tools.ietf.org/html/rfc7208"
+                    "#section-5.5"
+                )
+            elif mechanism == "rr":
+                tokens = value.split(":")
+
+                for token in tokens:
+                    if token not in ["all", "e", "f", "s", "n"]:
+                        raise SPFSyntaxError(
+                            f"{token} is not a valid token for the rr tag"
+                        )
+
+                parsed["rr"] = result
+            elif mechanism == "rp":
+                if not value.isdigit():
+                    raise SPFSyntaxError(
+                        f"{value} is not a valid ra tag value - should be a number"
+                    )
+                if int(value) < 0 or int(value) > 100:
+                    raise SPFSyntaxError(
+                        f"{value} is not a valid ra tag value - should be a number between 0 and 100"
+                    )
+
+                parsed["rp"] = result
             else:
                 parsed[result].append(
-                    OrderedDict([("value", value), ("mechanism", mechanism)]))
+                    OrderedDict([("value", value), ("mechanism", mechanism)])
+                )
 
         except (_SPFWarning, DNSException) as warning:
             if isinstance(warning, (_SPFMissingRecords, DNSExceptionNXDOMAIN)):
@@ -470,17 +544,25 @@ def parse_spf_record(
                         f"{void_lookup_mechanism_count}/2 maximum void DNS "
                         "lookups - "
                         "https://tools.ietf.org/html/rfc7208#section-4.6.4",
-                        dns_void_lookups=void_lookup_mechanism_count)
+                        dns_void_lookups=void_lookup_mechanism_count,
+                    )
             warnings.append(str(warning))
     return OrderedDict(
-        [('dns_lookups', lookup_mechanism_count),
-         ('dns_void_lookups', void_lookup_mechanism_count),
-         ("parsed", parsed), ("warnings", warnings)])
+        [
+            ("dns_lookups", lookup_mechanism_count),
+            ("dns_void_lookups", void_lookup_mechanism_count),
+            ("parsed", parsed),
+            ("warnings", warnings),
+        ]
+    )
 
 
-def get_spf_record(domain: str, nameservers: list[str] = None,
-                   resolver: dns.resolver.Resolver = None,
-                   timeout: float = 2.0) -> OrderedDict:
+def get_spf_record(
+    domain: str,
+    nameservers: list[str] = None,
+    resolver: dns.resolver.Resolver = None,
+    timeout: float = 2.0,
+) -> OrderedDict:
     """
     Retrieves and parses an SPF record
 
@@ -502,20 +584,25 @@ def get_spf_record(domain: str, nameservers: list[str] = None,
         :exc:`checkdmarc.SPFTooManyDNSLookups`
 
     """
-    record = query_spf_record(domain, nameservers=nameservers,
-                              resolver=resolver, timeout=timeout)
+    record = query_spf_record(
+        domain, nameservers=nameservers, resolver=resolver, timeout=timeout
+    )
     record = record["record"]
-    parsed_record = parse_spf_record(record, domain, nameservers=nameservers,
-                                     resolver=resolver, timeout=timeout)
+    parsed_record = parse_spf_record(
+        record, domain, nameservers=nameservers, resolver=resolver, timeout=timeout
+    )
     parsed_record["record"] = record
 
     return parsed_record
 
 
-def check_spf(domain: str, parked: bool = False,
-              nameservers: list[str] = None,
-              resolver: dns.resolver.Resolver = None,
-              timeout: float = 2.0) -> OrderedDict:
+def check_spf(
+    domain: str,
+    parked: bool = False,
+    nameservers: list[str] = None,
+    resolver: dns.resolver.Resolver = None,
+    timeout: float = 2.0,
+) -> OrderedDict:
     """
     Returns a dictionary with a parsed SPF record or an error.
 
@@ -544,26 +631,30 @@ def check_spf(domain: str, parked: bool = False,
                       - ``valid`` - False
     """
     spf_results = OrderedDict(
-        [("record", None), ("valid", True), ("dns_lookups", None),
-         ("dns_void_lookups", None)])
+        [
+            ("record", None),
+            ("valid", True),
+            ("dns_lookups", None),
+            ("dns_void_lookups", None),
+        ]
+    )
     try:
         spf_query = query_spf_record(
-            domain,
-            nameservers=nameservers, resolver=resolver,
-            timeout=timeout)
+            domain, nameservers=nameservers, resolver=resolver, timeout=timeout
+        )
         spf_results["record"] = spf_query["record"]
         spf_results["warnings"] = spf_query["warnings"]
-        parsed_spf = parse_spf_record(spf_results["record"],
-                                      domain,
-                                      parked=parked,
-                                      nameservers=nameservers,
-                                      resolver=resolver,
-                                      timeout=timeout)
+        parsed_spf = parse_spf_record(
+            spf_results["record"],
+            domain,
+            parked=parked,
+            nameservers=nameservers,
+            resolver=resolver,
+            timeout=timeout,
+        )
 
-        spf_results["dns_lookups"] = parsed_spf[
-            "dns_lookups"]
-        spf_results["dns_void_lookups"] = parsed_spf[
-            "dns_void_lookups"]
+        spf_results["dns_lookups"] = parsed_spf["dns_lookups"]
+        spf_results["dns_void_lookups"] = parsed_spf["dns_void_lookups"]
         spf_results["parsed"] = parsed_spf["parsed"]
         spf_results["warnings"] += parsed_spf["warnings"]
     except SPFError as error:
